@@ -26,7 +26,9 @@ except ImportError:
         del args, kwargs
         return iterable
 
+
 import sys
+
 SCRIPT_DIR = Path(__file__).absolute().parent
 sys.path.append(str(SCRIPT_DIR.parent))
 
@@ -35,7 +37,9 @@ from shithappens.utils import merge_pdfs, slugify
 
 
 def install_lang(locale: str):
-    locale_res = resources.files("shithappens.locales").joinpath(locale + "/LC_MESSAGES/shithappens.mo")
+    locale_res = resources.files("shithappens.locales").joinpath(
+        locale + "/LC_MESSAGES/shithappens.mo"
+    )
     with resources.as_file(locale_res) as locale_file:
         localedir = locale_file.parent.parent.parent
     lang = gettext.translation("shithappens", localedir=localedir, languages=[locale])
@@ -51,18 +55,44 @@ def text_with_wrap_autofit(
     height: float,
     *,
     min_font_size=None,
+    bleed: Optional[float] = None,
+    pad: Optional[float] = None,
     transform: Optional[Transform] = None,
     ha: Literal["left", "center", "right"] = "center",
     va: Literal["bottom", "center", "top"] = "center",
-    show_rect: bool = False,
     **kwargs,
 ):
-    """Automatically fits the text to some axes"""
+    """Automatically fits the text to some axes.
+
+    Args:
+        ax: axes to put the text on.
+        txt: text to display.
+        xy: location to place the text.
+        width: width of the text box.
+        height: height of the text box.
+        min_font_size: minimum acceptable font size.
+        bleed: bleed of the figure.
+        pad: padding of the box.
+        transform: matplotlib coordinate transformation.
+        ha: horizontal align.
+        va: vertical align.
+        **kwargs: keyword arguments passed to Axes.annotate.
+
+    Returns:
+        text artist.
+    """
     if transform is None:
         transform = ax.transData
 
     #  Different alignments give different bottom left and top right anchors.
     x, y = xy
+    if bleed:
+        x += bleed
+        y += bleed
+    if pad:
+        x += pad
+        y += pad
+
     xa0, xa1 = {
         "center": (x - width / 2, x + width / 2),
         "left": (x, x + width),
@@ -106,10 +136,6 @@ def text_with_wrap_autofit(
         wrap_lines += 1
     text.set_fontsize(adjusted_size)
 
-    if show_rect:
-        rect = Rectangle(a0, width, height, fill=False, ls="--")
-        ax.add_patch(rect)
-
     return text
 
 
@@ -118,7 +144,8 @@ class ShitHappensArgs(argparse.Namespace):
     name: str
     merge: bool
     side: Literal["front", "back", "both"]
-    lang: str
+    lang: Literal["en", "nl"]
+    format: Literal["pdf", "png"]
     workers: int
     chunks: int
 
@@ -210,13 +237,14 @@ def plot_card_front(card: Card) -> Figure:
     text_with_wrap_autofit(
         ax,
         card.desc.upper(),
-        (0.5, 0.8),
-        0.8,
-        0.5,
+        (0.5, 0.9),
+        0.7,
+        0.4,
         **text_kwargs,
+        bleed=ax.transData.transform((bleed, bleed))[0],
         transform=ax.transAxes,
-        min_font_size=10,
-        verticalalignment="top",
+        min_font_size=11,
+        va="top",
         weight="extra bold",
         color="yellow",
     )
@@ -300,7 +328,7 @@ def plot_card_back(card: Card, input_dir: Path) -> Figure:
         game_name.upper(),
         **text_kwargs,
         color="yellow",
-        fontsize=17,
+        fontsize=20,
         weight="regular",
         verticalalignment="center",
     )
@@ -315,40 +343,33 @@ def plot_card_back(card: Card, input_dir: Path) -> Figure:
 
     ax.text(
         x_size / 2 + bleed,
-        0.85 * y_size + bleed,
+        0.83 * y_size + bleed,
         expansion_text_full.upper(),
         **text_kwargs,
         color="yellow",
-        fontsize=7,
+        fontsize=14,
         fontstyle="italic",
         weight="ultralight",
         verticalalignment="center",
     )
 
-    # Game logo.
-    game_logo_path = f"{input_dir}/images/game-logo.png"
-    if not Path(game_logo_path).exists():
-        game_logo = resources.files("shithappens.images").joinpath("game-logo.png")
-        with resources.as_file(game_logo) as fpath:
-            game_logo_path = str(fpath)
-    game_logo = mpimage.imread(game_logo_path)[:, :, 0]
+    # Expansion logo
 
-    game_logoax = fig.add_axes([0.1, 0.3, 0.8, 0.4])
-    game_logoax.imshow(game_logo, cmap="binary")
-    game_logoax.axis("off")
-
-    # Expansion logo.
-    expansion_logo_path = f"{input_dir}/images/expansion-logo.png"
-    if not Path(expansion_logo_path).exists():
+    try:
+        expansion_logo_path = glob(f"{input_dir}/**/expansion-logo.*")[0]
+    except KeyError:
         expansion_logo = resources.files("shithappens.images").joinpath(
             "expansion-logo.png"
         )
         with resources.as_file(expansion_logo) as fpath:
             expansion_logo_path = str(fpath)
-    expansion_logo = mpimage.imread(str(expansion_logo_path))
 
-    expansion_logoax = fig.add_axes([0.1, 0.12, 0.8, 0.1])
-    expansion_logoax.imshow(expansion_logo)
+    expansion_logo = mpimage.imread(expansion_logo_path)
+
+    expansion_logoax = fig.add_axes([0.2, 0.1, 0.6, 0.6])
+    expansion_logoax.imshow(
+        expansion_logo,
+    )
     expansion_logoax.axis("off")
 
     plot_crop_marks(ax, bleed)
@@ -366,37 +387,49 @@ def save_card(
     output_dir: Path,
     side: Literal["front", "back"],
     dpi: int = 300,
-    format: str = ".pdf",
+    format: str = "pdf",
 ) -> None:
 
-    output_dir = output_dir / side
+    side_fn = _("front") if side == "front" else _("back")
+
+    output_dir = output_dir / side_fn
 
     output_dir.mkdir(parents=True, exist_ok=True)
 
     fn = f"{card.misery_index}-{card.desc}"
     fn = slugify(fn)
-    save_fn = (output_dir / fn).with_suffix(format)
+    save_fn = (output_dir / fn).with_suffix("." + format)
 
     if side == "front":
         card.fig_front.savefig(
-            str(save_fn), format=save_fn.suffix[1:], pad_inches=0, dpi=dpi
+            str(save_fn),
+            format=save_fn.suffix[1:],
+            pad_inches=0,
+            dpi=dpi,
+            transparent=False,
         )
     elif side == "back":
         card.fig_back.savefig(
-            str(save_fn), format=save_fn.suffix[1:], pad_inches=0, dpi=dpi
+            str(save_fn),
+            format=save_fn.suffix[1:],
+            pad_inches=0,
+            dpi=dpi,
+            transparent=False,
         )
 
 
-def create_card(row, expansion_name, input_dir, output_dir, side):
+def create_card(
+    row, expansion_name, input_dir, output_dir, side, ext: Literal["pdf", "png"]
+):
     card = Card(row[1]["desc"], row[1]["misery_index"], expansion_name)
 
     if side == "front" or side == "both":
         card.fig_front = plot_card_front(card)
-        save_card(card, output_dir, "front")
+        save_card(card, output_dir, "front", format=ext)
 
     if side == "back" or side == "both":
         card.fig_back = plot_card_back(card, input_dir)
-        save_card(card, output_dir, "back")
+        save_card(card, output_dir, "back", format=ext)
 
 
 def create_cards(
@@ -406,6 +439,7 @@ def create_cards(
     output_dir: Path,
     merge: bool,
     side: Literal["front", "back", "both"],
+    ext: Literal["pdf", "png"],
     workers: int,
     chunks: int,
     locale: str,
@@ -418,22 +452,26 @@ def create_cards(
         input_dir=input_dir,
         output_dir=output_dir,
         side=side,
+        ext=ext,
     )
-    with Pool(workers, install_lang, (locale,)) as p:
-        desc = _("Plotting cards")
-        list(
-            tqdm(
-                p.imap_unordered(create_card_par, df.iterrows(), chunksize),
-                total=nmax,
-                desc=desc,
+    desc = _("Plotting cards")
+    if chunksize:
+        with Pool(workers, install_lang, (locale,)) as p:
+            list(
+                tqdm(
+                    p.imap_unordered(create_card_par, df.iterrows(), chunksize),
+                    total=nmax,
+                    desc=desc,
+                )
             )
-        )
+    else:
+        list(tqdm(map(create_card_par, df.iterrows()), total=nmax, desc=desc))
 
     if merge:
         if side == "front" or side == "both":
-            merge_pdfs(output_dir / "front")
+            merge_pdfs(output_dir / _("front"))
         if side == "back" or side == "both":
-            merge_pdfs(output_dir / "back")
+            merge_pdfs(output_dir / _("back"))
 
 
 def main() -> None:
@@ -481,10 +519,17 @@ def main() -> None:
     options_group.add_argument(
         "-l",
         "--lang",
-        help="Language. Defaults to 'en'.",
+        help="Language. 'en' and 'nl' supported. Defaults to 'en'.",
         choices=["en", "nl"],
         default="en",
     )
+    options_group.add_argument(
+        "-f",
+        "--format",
+        help="Output format. 'pdf' and 'png' supported. Defaults to 'pdf'.",
+        choices=["pdf", "png"],
+        default="pdf",
+    )
 
     multiprocessing_group = arg_parser.add_argument_group("multiprocessing")
 
@@ -568,6 +613,7 @@ def main() -> None:
         output_dir,
         args.merge,
         args.side,
+        args.format,
         args.workers,
         args.chunks,
         args.lang,
